==> unknown-horizons_2011.2-1+5.0trisquel1.tar.gz: source/horizons/world/building/boatbuilder.py <==
# ###################################################
# Copyright (C) 2011 The Unknown Horizons Team
# team@unknown-horizons.org
# This file is part of Unknown Horizons.
#
# Unknown Horizons is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the
# Free Software Foundation, Inc.,
# 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
# ###################################################


from building import BasicBuilding, SelectableBuilding
from buildable import BuildableSingleOnCoast
from horizons.gui.tabs import BoatbuilderTab, BoatbuilderFisherTab, BoatbuilderTradeTab, \
			     BoatbuilderWar1Tab, BoatbuilderWar2Tab, BoatbuilderConfirmTab
from horizons.world.production.producer import UnitProducerBuilding
from collectingbuilding import CollectingBuilding

class BoatBuilder(SelectableBuilding, UnitProducerBuilding, CollectingBuilding, BuildableSingleOnCoast, BasicBuilding):
	tabs = (BoatbuilderTab, BoatbuilderFisherTab)
# , BoatbuilderTradeTab, BoatbuilderWar1Tab, BoatbuilderWar2Tab, BoatbuilderConfirmTab)
# not visible in release 2010.1

	def __init__(self, **kwargs):
		super(BoatBuilder, self).__init__(**kwargs)
		self.inventory.limit = 10

==> unknown-horizons_2011.3-1+5.5trisquel1.tar.gz: source/horizons/world/building/boatbuilder.py <==
# ###################################################
# Copyright (C) 2011 The Unknown Horizons Team
# team@unknown-horizons.org
# This file is part of Unknown Horizons.
#
# Unknown Horizons is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the
# Free Software Foundation, Inc.,
# 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
# ###################################################


from building import BasicBuilding, SelectableBuilding
from buildable import BuildableSingleOnOcean
from horizons.gui.tabs import BoatbuilderTab, BoatbuilderFisherTab, BoatbuilderTradeTab, \
			     BoatbuilderWar1Tab, BoatbuilderWar2Tab, BoatbuilderConfirmTab
from horizons.world.production.producer import UnitProducerBuilding
from collectingbuilding import CollectingBuilding

class BoatBuilder(SelectableBuilding, UnitProducerBuilding, CollectingBuilding, BuildableSingleOnOcean, BasicBuilding):
	tabs = (BoatbuilderTab, BoatbuilderFisherTab)
	tabs = (BoatbuilderTab, BoatbuilderTradeTab, BoatbuilderWar1Tab)
# , BoatbuilderTradeTab, BoatbuilderWar1Tab, BoatbuilderWar2Tab, BoatbuilderConfirmTab)
# not visible in release 2010.1

	def __init__(self, **kwargs):
		super(BoatBuilder, self).__init__(**kwargs)
		self.inventory.limit = 10
